"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runBuilder = void 0;
const tslib_1 = require("tslib");
const architect_1 = require("@angular-devkit/architect");
const core_1 = require("@nx-extend/core");
const path_1 = require("path");
function runBuilder(options, context) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { functionName, region, trigger = 'http', triggerValue = null, triggerEvent = null, runtime = 'nodejs14', allowUnauthenticated = true, envVarsFile = null, maxInstances = 10, project = null, memory = '128MB', serviceAccount = null, entryPoint = null, retry = false, ingressSettings = null, egressSettings = null, securityLevel = null } = options;
        const buildOptions = yield context.getTargetOptions({
            project: context.target && context.target.project,
            target: 'build'
        });
        const sourceDirectory = path_1.resolve(process.cwd(), buildOptions.outputPath.toString());
        context.logger.info(`Deploy function "${functionName}" with source from "${sourceDirectory}"`);
        return core_1.execCommand(core_1.buildCommand([
            'gcloud functions deploy',
            functionName,
            `--trigger-${trigger}${triggerValue ? `=${triggerValue}` : ''}`,
            triggerEvent && `--trigger-event=${triggerEvent}`,
            `--runtime=${runtime}`,
            `--memory=${memory}`,
            `--region=${region}`,
            entryPoint && `--entry-point=${entryPoint}`,
            envVarsFile && `--env-vars-file=${envVarsFile}`,
            retry && `--retry`,
            ingressSettings && `--ingress-settings=${ingressSettings}`,
            egressSettings && `--egress-settings=${egressSettings}`,
            securityLevel && `--security-level=${securityLevel}`,
            `--source=${sourceDirectory}`,
            `--max-instances=${maxInstances}`,
            allowUnauthenticated && '--allow-unauthenticated',
            serviceAccount && `--service-account=${serviceAccount}`,
            project && `--project=${project}`
        ]));
    });
}
exports.runBuilder = runBuilder;
exports.default = architect_1.createBuilder(runBuilder);
//# sourceMappingURL=deploy.impl.js.map